@@ -11,8 +11,8 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 
-Version = '1.11'
-Build = '3'
+Version = '1.12'
+Build = '1'
 
 import sys
 import os
@@ -234,12 +234,12 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
 
           self.ui.authenticateButton.setEnabled(False)
           self.ui.injectionButton.setEnabled(False)
-          # self.ui.deauthenticateButton.setEnabled(True) ##INFO: uncomment when "executeDeauthenticate" is fixed.
+          self.ui.deauthenticateButton.setEnabled(True)
           
        # print "capture options: ", channel, bssid, pathTemp, encryption, essid
        os.system('osso-xterm -e "sudo %s/%s capture %s %s %s %s %s" &' % (pathMain, helperScript, channel, bssid, pathTemp, encryption, essid))
       
-    def executeDeauthenticate(self): #FIXME:: the essid should be the connected client's mac
+    def executeDeauthenticate(self): #FIXME:: the essid should be the connected client's mac; atm ignoring essid and just broadcasting. 
        '''Opens an xterm window that sends deauthentication packets.'''
        
        # print "deauthenticate options: ", bssid, essid
